from setuptools import setup, find_packages
long_description= '''Python module for ODU tasks'''
setup(name='odulib',
      version='1.2',
      url='https://github.com/deaflurryth/odulib',
      license='MIT',
      author='deaflurryth',
      author_email='deaflurryth@icloud.com',
      description='Add static script_dir() method to Path',
      zip_safe=False)